topology Package — cobra 0.2.0 documentation

### Navigation

- index
- modules |
- previous |
- cobra 0.2.0 documentation »
- cobra Package »

# topology Package

## `topology` Package

## `reporter_metabolites` Module

`cobra.topology.reporter_metabolites.` `identify_reporter_metabolites`(cobra_model, reaction_scores_dict, number_of_randomizations=1000, number_of_layers=1, scoring_metric='default', score_type='p', entire_network=False, background_correction=True, ignore_external_boundary_reactions=False)

  Calculate the aggregate Z-score for the metabolites in the model. Ignore reactions that are solely spontaneous or orphan. Allow the scores to have multiple columns / experiments. This will change the way the output is represented.

  cobra_model: A cobra.Model object

  TODO: CHANGE TO USING DICTIONARIES for the_reactions: the_scores

  reaction_scores_dict: A dictionary where the keys are reactions in cobra_model.reactions and the values are the scores. Currently, only supports a single numeric value as the value; however, this will be updated to allow for lists

  number_of_randomizations: Integer. Number of random shuffles of the scores to assess which are significant.

  number_of_layers: 1 is the only option supported

  scoring_metric: default means divide by k**0.5

  score_type: ‘p’ Is the only option at the moment and indicates p-value.

  entire_network: Boolean. Currently, only compares scores calculated from the_reactions

  background_correction: Boolean. If True apply background correction to the aggreagate Z-score

  ignore_external_boundary_reactions: Not yet implemented. Boolean. If True do not count exchange reactions when calculating the score.

`cobra.topology.reporter_metabolites.` `ppmap_identify_reporter_metabolites`(keywords)

  A function that receives a dict with all of the parameters for identify_reporter_metabolites Serves to make it possible to call the reporter metabolites function from ppmap. It only will be useful for parallel experiments not for breaking up a single experiment.

### Navigation

- index
- modules |
- previous |
- cobra 0.2.0 documentation »
- cobra Package »